<!-- Git thumbnail - shows git repository icon and info -->
<div class="extractor-thumbnail git-thumbnail" style="width: 100%; height: 100px; overflow: hidden; background: #f6f8fa; display: flex; flex-direction: column; align-items: center; justify-content: center; padding: 10px;">
    <span style="font-size: 32px;">📂</span>
    <span style="font-size: 11px; color: #586069; margin-top: 4px;">Git Repository</span>
</div>
