<!-- PDF fullscreen - full PDF viewer -->
<embed src="{{ output_path }}#toolbar=1&navpanes=1&view=FitH"
       type="application/pdf"
       class="extractor-fullscreen pdf-fullscreen"
       style="width: 100%; height: 100vh;">
