<span class="abx-output-icon abx-output-icon--title" title="Title"><svg width="16" height="16" viewBox="0 0 24 24" aria-hidden="true" focusable="false" fill="none" stroke="currentColor" stroke-width="1.8" stroke-linecap="round" stroke-linejoin="round"><path d="M3 11l8-8h9v9l-8 8-9-9z"/><circle cx="16" cy="7" r="1.5" fill="currentColor" stroke="none"/></svg></span>
