<!-- Readability thumbnail - shows reader-mode extracted article content -->
<div class="extractor-thumbnail readability-thumbnail" style="width: 100%; height: 100px; overflow: hidden; background: #fefefe; padding: 8px; font-family: Georgia, serif; font-size: 11px; line-height: 1.4; color: #333;">
    <iframe src="{{ output_path }}"
            style="width: 100%; height: 300px; border: none; pointer-events: none;"
            loading="lazy"
            fetchpriority="low"
            sandbox="allow-same-origin">
    </iframe>
</div>
