<!-- Screenshot fullscreen - centered image with vertical scroll -->
<div style="width: 100%; min-height: 100vh; overflow: auto; background: #fff; padding: 0; box-sizing: border-box;">
    <div style="width: 100%; min-width: 100%; display: flex; flex-direction: column; align-items: center; justify-content: flex-start;">
        <img src="{{ output_path }}"
             alt="Screenshot of page"
             class="extractor-fullscreen screenshot-fullscreen"
             style="width: auto; max-width: 100%; height: auto; display: block; margin: 0 auto;">
    </div>
</div>
