<!-- Readability fullscreen - show extracted article HTML -->
<iframe class="full-page-iframe"
        src="{{ output_path }}"
        name="preview"
        sandbox="allow-same-origin allow-top-navigation-by-user-activation allow-scripts allow-forms">
</iframe>
