<span class="abx-output-icon abx-output-icon--readability" title="Readability"><svg width="16" height="16" viewBox="0 0 24 24" aria-hidden="true" focusable="false" fill="none" stroke="currentColor" stroke-width="1.8" stroke-linecap="round" stroke-linejoin="round"><path d="M3 6h7a3 3 0 0 1 3 3v10H6a3 3 0 0 0-3 3z"/><path d="M21 6h-7a3 3 0 0 0-3 3v10h7a3 3 0 0 1 3 3z"/></svg></span>
